@@ -122,7 +122,6 @@ CREATE TABLE runs (
 
     -- User Input
     added           TIMESTAMP       NOT NULL DEFAULT now(),
-    status_changed  TIMESTAMP       NOT NULL DEFAULT now(),
     log_file_id     CHAR(36)        DEFAULT NULL,
 
     mode ENUM('qvfd', 'qvf', 'summary', 'complete') NOT NULL,
@@ -144,26 +143,6 @@ CREATE INDEX run_projects ON runs(project_id);
 CREATE INDEX run_status ON runs(status);
 CREATE INDEX run_user ON runs(user_id);
 
--- CREATE OR REPLACE FUNCTION update_status_changed() RETURNS TRIGGER LANGUAGE plpgsql AS $$
--- BEGIN
---     IF (NEW.status != OLD.status) THEN
---         NEW.status_changed = now();
---     END IF;
---     RETURN NEW;
--- END;
--- $$;
-delimiter //
-CREATE TRIGGER status_changed
-  BEFORE UPDATE
-  ON runs
-  FOR EACH ROW
-  BEGIN
-    IF NEW.status != OLD.status THEN
-        SET NEW.status_changed = now();
-    END IF;
-  END;//
-delimiter ;
-
 CREATE TABLE jobs (
     job_key         CHAR(36)    NOT NULL PRIMARY KEY,
 
@@ -222,6 +201,7 @@ CREATE TABLE events (
     job_key         CHAR(36)    NOT NULL REFERENCES jobs(job_key),
 
     event_ord       BIGINT      NOT NULL,
+    insert_ord      BIGINT      NOT NULL AUTO_INCREMENT,
 
     is_diag         BOOL        NOT NULL DEFAULT FALSE,
     is_harness      BOOL        NOT NULL DEFAULT FALSE,
@@ -239,6 +219,7 @@ CREATE TABLE events (
     orphan          LONGTEXT  DEFAULT NULL,
     orphan_line     BIGINT      DEFAULT NULL,
 
+    UNIQUE(insert_ord),
     FOREIGN KEY (job_key) REFERENCES jobs(job_key)
 ) ROW_FORMAT=COMPRESSED;
 CREATE INDEX event_job    ON events(job_key);
